summaryrefslogtreecommitdiff
path: root/cmd/pggraph/main.go
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/pggraph/main.go')
-rw-r--r--cmd/pggraph/main.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/cmd/pggraph/main.go b/cmd/pggraph/main.go
index 59946ad..c7909b5 100644
--- a/cmd/pggraph/main.go
+++ b/cmd/pggraph/main.go
@@ -3,7 +3,7 @@
// license that can be found in the LICENSE file.
// pggraph creates a graph showing the proportion of black pixels
// for slices through an image. This is useful to determine
// appropriate parameters to pass to the wipe functions in this
// module.
package main
@@ -27,8 +27,8 @@ import (
const usage = `Usage: pggraph [-vertical] [-width] inimg graphname
-Creates a graph showing the proportion of black pixels
-for slices through an image. This is useful to determine
+Creates a graph showing the proportion of black pixels for
+slices through a binarised image. This is useful to determine
appropriate parameters to pass to the wipe functions in
this module.
`
@@ -3,7 +3,7 @@
// license that can be found in the LICENSE file.
// pggraph creates a graph showing the proportion of black pixels
-// for slices through an image. This is useful to determine
+// for slices through a binarised image. This is useful to determine
// appropriate parameters to pass to the wipe functions in this
// module.